@@ -58,10 +58,8 @@ def _batch_records_helper(
         for k in common_dimensions.get_dimension_keys():
             if dimensions.get_dimension(k) == common_dimensions.get_dimension(k):
                 shared[k] = True
-        # DEFAULT_LOGGER.info(f"SHARED {shared}")
         # Add the record to the batch if it has the minimum number of shared dimensions
         if len(shared) >= min_common_dimensions:
-            DEFAULT_LOGGER.info(f"SHARED >= MCD {len(shared)}")
             keys_to_remove = [k for k in common_dimensions.get_dimension_keys() if k not in shared]
             for k in keys_to_remove:
                 common_dimensions.remove_dimension(k)
